@@ -15,7 +15,7 @@ def test_client_requires_model_name() -> None:
             assistant_model_url="https://example.test",
             assistant_model_api_key="k",
             assistant_model_name="",
-            persona_api_key="demo-001",
+            steer_api_key="demo-001",
         )
 
 
@@ -25,7 +25,7 @@ def test_simulation_runner_lazy_instantiation() -> None:
         assistant_model_url="https://example.test",
         assistant_model_api_key="test-key",
         assistant_model_name="gpt-test",
-        persona_api_key="demo-001",
+        steer_api_key="demo-001",
     )
     runner = client.simulation_runner
     assert isinstance(runner, SimulationRunner)
